package com.diagbot.web;

import com.diagbot.annotation.SysLogger;
import com.diagbot.dto.RespDTO;
import com.diagbot.facade.CacheFacade;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
 * 缓存 前端控制器
 * </p>
 *
 * @author zhoutg
 * @since 2018-12-25
 */
@RequestMapping("/cache")
@RestController
@SuppressWarnings("unchecked")
@Api(value = "缓存API", tags = { "缓存API" })
public class CacheController {

    @Autowired
    CacheFacade cacheFacade;

    @ApiOperation(value = "清除启动加载类缓存[by:zhoutg]",
            notes = "")
    @PostMapping("/clear")
    @SysLogger("clear")
    public RespDTO<Boolean> clear() {
        cacheFacade.clear();
        cacheFacade.loadDrugTypeCache();
        cacheFacade.getDiseaseCorrespondCache();
        cacheFacade.getdiseaseFilterCache();
        cacheFacade.loadAllRuleCache();
        cacheFacade.loadAllBaseDiagnoseCache();
        //无用的缓存
//        cacheFacade.loadDiseaseTypeCache();
//        cacheFacade.getSymptomCache();
//        cacheFacade.getSymptomMainCache();
//        cacheFacade.getVitalCache();
//        cacheFacade.getSymptomNumCache();
//        cacheFacade.getSymptomFeatureCache();
        return RespDTO.onSuc(true);
    }

    @ApiOperation(value = "重新加载基础诊断依据[by:zhoutg]",
            notes = "")
    @PostMapping("/reloadDiagnose")
    @SysLogger("reloadDiagnose")
    public RespDTO<Boolean> reloadDiagnose() {
        cacheFacade.loadAllBaseDiagnoseCache();
        return RespDTO.onSuc(true);
    }

    @ApiOperation(value = "重新加载药物缓存[by:zhoutg]",
            notes = "")
    @PostMapping("/clearDrug")
    @SysLogger("clearDrug")
    public RespDTO<Boolean> clearDrug() {
        cacheFacade.loadDrugTypeCache();
        return RespDTO.onSuc(true);
    }

    @ApiOperation(value = "清除标准词转换缓存[by:zhoutg]",
            notes = "")
    @PostMapping("/clearStandConvert")
    @SysLogger("clearStandConvert")
    public RespDTO<Boolean> clearStandConvert() {
        cacheFacade.clearStandConvert();
        return RespDTO.onSuc(true);
    }

    @ApiOperation(value = "清除规则缓存[by:wangfeng]",
            notes = "")
    @PostMapping("/clearRuleInfoAll")
    @SysLogger("clearRuleInfoAll")
    public RespDTO<Boolean> clearRuleInfoAlls() {
        cacheFacade.loadAllRuleCache();
        return RespDTO.onSuc(true);
    }

    @ApiOperation(value = "重新加载大数据缓存[by:zhoutg]",
            notes = "")
    @PostMapping("/reloadPushDB")
    @SysLogger("reloadPushDB")
    public RespDTO<Boolean> reloadPushDB() {
        boolean flag = cacheFacade.reloadPushDB();
        if (flag) {
            return RespDTO.onSuc(flag);
        } else {
            return RespDTO.onError("加载大数据缓存失败");
        }
    }

    @ApiOperation(value = "重新加载标准词及规则、药物缓存、基础诊断依据[by:wangfeng]",
            notes = "")
    @PostMapping("/clearStandRuleDrug")
    @SysLogger("clearStandRuleDrug")
    public RespDTO<Boolean> clearStandRuleDrugAll() {
        cacheFacade.clearStandConvert();
        cacheFacade.loadAllRuleCache();
        cacheFacade.loadDrugTypeCache();
        cacheFacade.loadAllBaseDiagnoseCache();
        // 加载大数据缓存
        boolean flag = cacheFacade.reloadPushDB();
        if (flag) {
            return RespDTO.onSuc(flag);
        } else {
            return RespDTO.onError("加载知识库缓存成功，加载大数据缓存失败");
        }
    }

    @ApiOperation(value = "加载大数据推送类型【字段：push_mode】和推送版本【字段：remark】[by:zhoutg]",
            notes = "表：tran_hospital_info，【remark】字段：old表示使用原5.0推理，其他值：新版推理")
    @PostMapping("/loadHostipalPush")
    @SysLogger("loadHostipalPush")
    public RespDTO<Boolean> loadHostipalPush() {
        cacheFacade.loadHostipalPush();
        return RespDTO.onSuc(true);
    }
}
